{% extends "base.html" %} {% set section = "downloads" %} {% block body %} {% if downloads %}

Download | Size | Type | Date {% if user.admin %} | User {% endif %}
{% for dl in downloads %}
{{ dl.description }} | {{ dl.size|filesizeformat }} | {{ mediatypes[dl.media_type] }} | {{ dl.completed|timestampformat('%Y/%m/%d %H:%M') }} {% if user.admin %} | {{ dl.user.username }} {% endif %}
{% endfor %}

{% else %}

There are no downloads recorded.